GoogleApi.GameServices.V1.Model.DeployedFleetAutoscaler (google_api_game_services v0.7.0) View Source
Details about the Agones autoscaler.
Attributes
-
autoscaler(type:String.t, default:nil) - The name of the Agones autoscaler. -
fleetAutoscalerSpec(type:String.t, default:nil) - The autoscaler spec retrieved from Agones. -
specSource(type:GoogleApi.GameServices.V1.Model.SpecSource.t, default:nil) - The source spec that is used to create the autoscaler. The GameServerConfig resource may no longer exist in the system.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.GameServices.V1.Model.DeployedFleetAutoscaler{
autoscaler: String.t(),
fleetAutoscalerSpec: String.t(),
specSource: GoogleApi.GameServices.V1.Model.SpecSource.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.