GoogleApi.GameServices.V1.Model.PreviewGameServerDeploymentRolloutResponse (google_api_game_services v0.7.0) View Source
Response message for PreviewGameServerDeploymentRollout. This has details about the Agones fleet and autoscaler to be actuated.
Attributes
-
etag(type:String.t, default:nil) - ETag of the game server deployment. -
targetState(type:GoogleApi.GameServices.V1.Model.TargetState.t, default:nil) - The target state. -
unavailable(type:list(String.t), default:nil) - Locations that could not be reached on this request.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.GameServices.V1.Model.PreviewGameServerDeploymentRolloutResponse{
etag: String.t(),
targetState: GoogleApi.GameServices.V1.Model.TargetState.t(),
unavailable: [String.t()]
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.