GoogleApi.GameServices.V1.Model.Rule (google_api_game_services v0.7.0) View Source
A rule to be applied in a Policy.
Attributes
-
action(type:String.t, default:nil) - Required -
conditions(type:list(GoogleApi.GameServices.V1.Model.Condition.t), default:nil) - Additional restrictions that must be met. All conditions must pass for the rule to match. -
description(type:String.t, default:nil) - Human-readable description of the rule. -
in(type:list(String.t), default:nil) - If one or more 'in' clauses are specified, the rule matches if the PRINCIPAL/AUTHORITY_SELECTOR is in at least one of these entries. -
logConfig(type:list(GoogleApi.GameServices.V1.Model.LogConfig.t), default:nil) - The config returned to callers of tech.iam.IAM.CheckPolicy for any entries that match the LOG action. -
notIn(type:list(String.t), default:nil) - If one or more 'not_in' clauses are specified, the rule matches if the PRINCIPAL/AUTHORITY_SELECTOR is in none of the entries. The format for in and not_in entries can be found at in the Local IAM documentation (see go/local-iam#features). -
permissions(type:list(String.t), default:nil) - A permission is a string of form '..' (e.g., 'storage.buckets.list'). A value of '' matches all permissions, and a verb part of '' (e.g., 'storage.buckets.*') matches all verbs.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.GameServices.V1.Model.Rule{
action: String.t(),
conditions: [GoogleApi.GameServices.V1.Model.Condition.t()],
description: String.t(),
in: [String.t()],
logConfig: [GoogleApi.GameServices.V1.Model.LogConfig.t()],
notIn: [String.t()],
permissions: [String.t()]
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.