GoogleApi.GameServices.V1.Model.ScalingConfig (google_api_game_services v0.7.0) View Source
Autoscaling config for an Agones fleet.
Attributes
-
fleetAutoscalerSpec(type:String.t, default:nil) - Required. Agones fleet autoscaler spec. Example spec: https://agones.dev/site/docs/reference/fleetautoscaler/ -
name(type:String.t, default:nil) - Required. The name of the Scaling Config -
schedules(type:list(GoogleApi.GameServices.V1.Model.Schedule.t), default:nil) - The schedules to which this Scaling Config applies. -
selectors(type:list(GoogleApi.GameServices.V1.Model.LabelSelector.t), default:nil) - Labels used to identify the game server clusters to which this Agones scaling config applies. A game server cluster is subject to this Agones scaling config if its labels match any of the selector entries.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.GameServices.V1.Model.ScalingConfig{
fleetAutoscalerSpec: String.t(),
name: String.t(),
schedules: [GoogleApi.GameServices.V1.Model.Schedule.t()],
selectors: [GoogleApi.GameServices.V1.Model.LabelSelector.t()]
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.