GoogleApi.GameServices.V1beta.Model.DeployedClusterState (google_api_game_services v0.7.0) View Source
The game server cluster changes made by the game server deployment.
Attributes
-
cluster(type:String.t, default:nil) - The name of the cluster. -
fleetDetails(type:list(GoogleApi.GameServices.V1beta.Model.DeployedFleetDetails.t), default:nil) - The details about the Agones fleets and autoscalers created in the game server cluster.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.GameServices.V1beta.Model.DeployedClusterState{
cluster: String.t(),
fleetDetails: [GoogleApi.GameServices.V1beta.Model.DeployedFleetDetails.t()]
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.