GoogleApi.GameServices.V1beta.Model.DeployedFleet (google_api_game_services v0.7.0) View Source
Agones fleet specification and details.
Attributes
-
fleet(type:String.t, default:nil) - The name of the Agones fleet. -
fleetSpec(type:String.t, default:nil) - The fleet spec retrieved from the Agones fleet. -
specSource(type:GoogleApi.GameServices.V1beta.Model.SpecSource.t, default:nil) - The source spec that is used to create the Agones fleet. The GameServerConfig resource may no longer exist in the system. -
status(type:GoogleApi.GameServices.V1beta.Model.DeployedFleetStatus.t, default:nil) - The current status of the Agones fleet. Includes count of game servers in various states.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.GameServices.V1beta.Model.DeployedFleet{
fleet: String.t(),
fleetSpec: String.t(),
specSource: GoogleApi.GameServices.V1beta.Model.SpecSource.t(),
status: GoogleApi.GameServices.V1beta.Model.DeployedFleetStatus.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.