GoogleApi.GameServices.V1beta.Model.GameServerDeploymentRollout (google_api_game_services v0.7.0) View Source
The game server deployment rollout which represents the desired rollout state.
Attributes
-
createTime(type:DateTime.t, default:nil) - Output only. The creation time. -
defaultGameServerConfig(type:String.t, default:nil) - The default game server config is applied to all realms unless overridden in the rollout. For example,projects/my-project/locations/global/gameServerDeployments/my-game/configs/my-config. -
etag(type:String.t, default:nil) - ETag of the resource. -
gameServerConfigOverrides(type:list(GoogleApi.GameServices.V1beta.Model.GameServerConfigOverride.t), default:nil) - Contains the game server config rollout overrides. Overrides are processed in the order they are listed. Once a match is found for a realm, the rest of the list is not processed. -
name(type:String.t, default:nil) - The resource name of the game server deployment rollout, in the following form:projects/{project}/locations/{location}/gameServerDeployments/{deployment}/rollout. For example,projects/my-project/locations/global/gameServerDeployments/my-deployment/rollout. -
updateTime(type:DateTime.t, default:nil) - Output only. The last-modified time.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.GameServices.V1beta.Model.GameServerDeploymentRollout{
createTime: DateTime.t(),
defaultGameServerConfig: String.t(),
etag: String.t(),
gameServerConfigOverrides: [
GoogleApi.GameServices.V1beta.Model.GameServerConfigOverride.t()
],
name: String.t(),
updateTime: DateTime.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.