GoogleApi.GameServices.V1beta.Model.GkeHubClusterReference (google_api_game_services v0.7.0) View Source
GkeHubClusterReference represents a reference to a Kubernetes cluster registered through GKE Hub.
Attributes
-
membership(type:String.t, default:nil) - The full or partial name of a GKE Hub membership, using one of the following forms:https://gkehub.googleapis.com/v1beta1/projects/{project_id}/locations/global/memberships/{membership_id}projects/{project_id}/locations/global/memberships/{membership_id}*{membership_id}If project is not specified, the project of the GameServerCluster resource is used to generate the full name of the GKE Hub membership.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.GameServices.V1beta.Model.GkeHubClusterReference{
membership: String.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.