GoogleApi.GameServices.V1beta.Model.ListGameServerConfigsResponse (google_api_game_services v0.7.0) View Source
Response message for GameServerConfigsService.ListGameServerConfigs.
Attributes
-
gameServerConfigs(type:list(GoogleApi.GameServices.V1beta.Model.GameServerConfig.t), default:nil) - The list of game server configs. -
nextPageToken(type:String.t, default:nil) - Token to retrieve the next page of results, or empty if there are no more results in the list. -
unreachable(type:list(String.t), default:nil) - List of locations that could not be reached.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.GameServices.V1beta.Model.ListGameServerConfigsResponse{
gameServerConfigs: [GoogleApi.GameServices.V1beta.Model.GameServerConfig.t()],
nextPageToken: String.t(),
unreachable: [String.t()]
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.