GoogleApi.GameServices.V1beta.Model.Realm (google_api_game_services v0.7.0) View Source
A realm resource.
Attributes
-
createTime(type:DateTime.t, default:nil) - Output only. The creation time. -
description(type:String.t, default:nil) - Human readable description of the realm. -
etag(type:String.t, default:nil) - ETag of the resource. -
labels(type:map(), default:nil) - The labels associated with this realm. Each label is a key-value pair. -
name(type:String.t, default:nil) - The resource name of the realm, in the following form:projects/{project}/locations/{location}/realms/{realm}. For example,projects/my-project/locations/{location}/realms/my-realm. -
timeZone(type:String.t, default:nil) - Required. Time zone where all policies targeting this realm are evaluated. The value of this field must be from the IANA time zone database: https://www.iana.org/time-zones. -
updateTime(type:DateTime.t, default:nil) - Output only. The last-modified time.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.GameServices.V1beta.Model.Realm{
createTime: DateTime.t(),
description: String.t(),
etag: String.t(),
labels: map(),
name: String.t(),
timeZone: String.t(),
updateTime: DateTime.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.