GoogleApi.GameServices.V1beta.Model.SpecSource (google_api_game_services v0.7.0) View Source
Encapsulates Agones fleet spec and Agones autoscaler spec sources.
Attributes
-
gameServerConfigName(type:String.t, default:nil) - The game server config resource. Uses the form:projects/{project}/locations/{location}/gameServerDeployments/{deployment_id}/configs/{config_id}. -
name(type:String.t, default:nil) - The name of the Agones leet config or Agones scaling config used to derive the Agones fleet or Agones autoscaler spec.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.